searchData={"items":[{"type":"module","doc":"Extends LiveView with `stream_async/4` macro.","title":"LiveStreamAsync","ref":"LiveStreamAsync.html"},{"type":"module","doc":"New release of [LiveView library - v 0.20](https://hexdocs.pm/phoenix_live_view/Phoenix.LiveView.html) - introduced built-in functions for [asynchronous work](https://hexdocs.pm/phoenix_live_view/0.20.14/Phoenix.LiveView.html#module-async-operations).  It's a perfect solution to deliver a snappy user experience by delegating some time-consuming tasks (ex. fetching from external services) to background jobs without blocking the UI or event handlers. New operations include:\n\n- `assign_sync/3`: a straight forward way to load the results asynchronously into socket assigns.\n- `start_async/4`: allows lower level control of asynchronous operations with `handle_async` callbacks.\n- `<.async_result ...>` - function component to handle the asynchronous operation state on the UI side (for success, loading and errors).","title":"New asynchronous operations in LiveView v.20 - LiveStreamAsync","ref":"LiveStreamAsync.html#module-new-asynchronous-operations-in-liveview-v-20"},{"type":"module","doc":"Streams in LiveView allow working with large collections without keeping them on the server. In case you want to work with `streams` assigns asynchronously you may need to resort to low level control functions.\n\nThis library provides a convenient macro `stream_async/4` that auto-generates all the necessary boilerplate behind the scenes and injects it into your LiveView module.","title":"Async streams - LiveStreamAsync","ref":"LiveStreamAsync.html#module-async-streams"},{"type":"module","doc":"","title":"Usage - LiveStreamAsync","ref":"LiveStreamAsync.html#module-usage"},{"type":"module","doc":"Extend your live view module with `use LiveAsyncStream` and you can leverage the `stream_async/4` macro:\n\n```elixir\nuse MyAppWeb, :live_view\nuse LiveAsyncStream\n\ndef mount(%{\"location\" => location}, _, socket) do\n{:ok,\nsocket\n|> stream_async(:hotels, fn -> Hotels.fetch!(location) end, reset: true)\n}\nend\n```","title":"Extending LiveView - LiveStreamAsync","ref":"LiveStreamAsync.html#module-extending-liveview"},{"type":"module","doc":"The `<.async_result ...>` component is designed to work with the `%Phoenix.LiveView.AsyncResult{}` structs. The struct is passed via \"`assign={}`\" attribute of the component. The component's inner block receives the `@streams` assign key through `:let={}` attribute. Example:\n```elixir\n  def render(assigns) do\n    ~H\"\"\"\n    <.async_result :let={stream_key} assign={@hotels}>\n    <:loading>Loading hotels...</:loading>\n    <:failed :let={_failure}>There was an error loading the hotels. Please try again later.</:failed>\n       \n         \n        <%= hotel.name %>\n         \n       \n    </.async_result>\n  \"\"\"\n  end\n```","title":"Accessing the result - LiveStreamAsync","ref":"LiveStreamAsync.html#module-accessing-the-result"},{"type":"macro","doc":"Assigns stream keys asynchronously.\n\nWraps your function in a task linked to the caller, errors are wrapped. The key passed to `stream_async/4` will be assigned to an `Phoenix.LiveView.AsyncResult` struct holding the status of the operation and the result - key to the streams assign (socket.assigns.streams) - when the function completes.\n\nThe task is only started when the socket is connected.","title":"LiveStreamAsync.stream_async/4","ref":"LiveStreamAsync.html#stream_async/4"},{"type":"macro","doc":"* `:supervisor` - allows you to specify a `Task.Supervisor` to supervise the task.\n* from `Phoenix.LiveView.stream/4` function:\n  * `:at` - the index to insert or update the items in the\n      collection on the client.\n  * `:reset` - the boolean to reset the stream on the client or not. Defaults\n    to `false`.\n  * `:limit` - the optional positive or negative number of results to limit\n    on the UI on the client.","title":"Options - LiveStreamAsync.stream_async/4","ref":"LiveStreamAsync.html#stream_async/4-options"},{"type":"macro","doc":"```elixir\n  use MyAppWeb, :live_view\n  use LiveAsyncStream\n\n  def mount(%{\"location\" => location}, _, socket) do\n  {:ok,\n  socket\n  |> stream_async(:hotels, fn -> Hotels.fetch!(location) end, reset: true)\n  }\n  end\n  ```","title":"Example - LiveStreamAsync.stream_async/4","ref":"LiveStreamAsync.html#stream_async/4-example"},{"type":"extras","doc":"# LiveStreamAsync\n\nExtends LiveView with `stream_async/4` macro.","title":"LiveStreamAsync","ref":"readme.html"},{"type":"extras","doc":"The package can be installed by adding `live_stream_async` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:live_stream_async, \"~> 0.1.0\", runtime: false}\n  ]\nend\n```\n\nThe docs can be found at  .","title":"Installation - LiveStreamAsync","ref":"readme.html#installation"},{"type":"extras","doc":"New release of [LiveView library - v 0.20](https://hexdocs.pm/phoenix_live_view/Phoenix.LiveView.html) - introduced built-in functions for [asynchronous work](https://hexdocs.pm/phoenix_live_view/0.20.14/Phoenix.LiveView.html#module-async-operations).  It's a perfect solution to deliver a snappy user experience by delegating some time-consuming tasks (ex. fetching from external services) to background jobs without blocking the UI or event handlers. New operations include:\n\n  - `assign_sync/3`: a straight forward way to load the results asynchronously into socket assigns.\n  - `start_async/4`: allows lower level control of asynchronous operations with `handle_async` callbacks.\n  - `<.async_result ...>` - function component to handle the asynchronous operation state on the UI side (for success, loading and errors).","title":"New asynchronous operations in LiveView v.20 - LiveStreamAsync","ref":"readme.html#new-asynchronous-operations-in-liveview-v-20"},{"type":"extras","doc":"Streams in LiveView allow working with large collections without keeping them on the server. In case you want to work with `streams` assigns asynchronously you may need to resort to low level control functions.\n\n  This library provides a convenient macro `stream_async/4` that auto-generates all the necessary boilerplate behind the scenes and injects it into your LiveView module.","title":"Async streams - LiveStreamAsync","ref":"readme.html#async-streams"},{"type":"extras","doc":"","title":"Usage - LiveStreamAsync","ref":"readme.html#usage"},{"type":"extras","doc":"Extend your live view module with `use LiveAsyncStream` and you can leverage the `stream_async/4` macro:\n\n  ```elixir\n  use MyAppWeb, :live_view\n  use LiveAsyncStream\n\n  def mount(%{\"location\" => location}, _, socket) do\n  {:ok,\n  socket\n  |> stream_async(:hotels, fn -> Hotels.fetch!(location) end, reset: true)\n  }\n  end\n  ```","title":"Extending LiveView - LiveStreamAsync","ref":"readme.html#extending-liveview"},{"type":"extras","doc":"The `<.async_result ...>` component is designed to work with the `%Phoenix.LiveView.AsyncResult{}` structs. The struct is passed via \"`assign={}`\" attribute of the component. The component's inner block receives the `@streams` assign key through `:let={}` attribute. Example:\n  ```elixir\n    def render(assigns) do\n      ~H\"\"\"\n      <.async_result :let={stream_key} assign={@hotels}>\n      <:loading>Loading hotels...</:loading>\n      <:failed :let={_failure}>There was an error loading the hotels. Please try again later.</:failed>\n         \n           \n          <%= hotel.name %>\n           \n         \n      </.async_result>\n    \"\"\"\n    end\n  ```","title":"Accessing the result - LiveStreamAsync","ref":"readme.html#accessing-the-result"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,48]}}